@@ -349,6 +349,8 @@ def find_peaks_maxima(x, y, ignore_local_maxima = False, to_plot = False, promin
         It enables to turn on the option to ignore local maxima points.
     to_plot : bool, optional, default: False
         Flag that determines whether to enable plotting or not.
+    prominence : float, optional, the default is None
+        Input to detemine the prominence threshold for the find_peak.
     Returns
     -------
     `numpy.ndarray`
@@ -1085,8 +1087,10 @@ def get_second_derivative(x, y):
 
 def interpolate_pchip(N, *args):
     '''
+
     The interpolant uses monotonic cubic splines to find the value of new points.
-     (PCHIP stands for Piecewise Cubic Hermite Interpolating Polynomial).
+    (PCHIP stands for Piecewise Cubic Hermite Interpolating Polynomial).
+
     Parameters
     ----------
     N : int/float
@@ -1094,6 +1098,7 @@ def interpolate_pchip(N, *args):
     *args :  `numpy.ndarray` (N, 2)/ np.array, np.array
         It the first column is for the coords vector, and the second column is for the potential. It can handle an input
         in the form of a 2-column matrix or two different array_like arguments.
+
     Returns
     -------
     new_coords : np.array,(n,)
@@ -1143,6 +1148,7 @@ def interpolate_pchip(N, *args):
 def interpolate_cubic(N, *args):
     '''
     Cubic interpolation.
+
     Parameters
     ----------
     N : int/float
@@ -1150,6 +1156,7 @@ def interpolate_cubic(N, *args):
     *args :  `numpy.ndarray` (N, 2)/ np.array, np.array
         It the first column is for the coords vector, and the second column is for the potential. It can handle an input
         in the form of a 2-column matrix or two different array_like arguments.
+
     Returns
     -------
     new_coords : np.array,(n,)
@@ -1364,6 +1371,7 @@ def to_2_column_mat(vec):
 def find_adjacent_minima_maxima(z,v,start_peak_pos,reverse = False,prominence=None):
     '''
     Very not elegnat and very complex method to find adjacent minima to maxima point in a locpot vector.
+
     Parameters
     ----------
     z : np.array
@@ -1377,6 +1385,7 @@ def find_adjacent_minima_maxima(z,v,start_peak_pos,reverse = False,prominence=No
     prominence : float, optional, default: None
         The prominence of the peak. It helps to detemine what peaks we wish relate during the calculation.
         For more inforamtion about this mathematical entity it is recommended to look for it on web (it has to be with topology in mathematics)
+
     Returns
     -------
     (int, float), (int, float)
@@ -1527,9 +1536,11 @@ def run_one_time_step(wave_function, time_step, v, z , k):
     time_step = cons.fs2sec(time_step)
     wave_function = force_psi_units(wave_function,units = 'Meter')
     if not is_normalized(z,wave_function,units = 'Meter'):
-        print('Psi was not normalized, Now it forces again normalization')
-        print(np.real(np.trapz(wave_function * np.conj(wave_function), z)))
-        wave_function = wave_function * normalize_wave_function_numerically(z,wave_function,units='Meter')
+        temp = np.real(np.trapz(wave_function * np.conj(wave_function), z))
+        if not 0.97 <= temp <= 1.03:
+            print('Psi was not normalized, Now it forces again normalization')
+            print(temp)
+            wave_function = wave_function * normalize_wave_function_numerically(z,wave_function,units='Meter')
     k = cons.m2A(k)
     temp_wave_function = np.exp(-1j*v * time_step/(2*cons.hbarJ)) * wave_function
     temp_wave_function = np.fft.fft(temp_wave_function)
@@ -1538,9 +1549,11 @@ def run_one_time_step(wave_function, time_step, v, z , k):
     temp_wave_function = np.exp(-1j*v * time_step/(2*cons.hbarJ)) * temp_wave_function
     temp_wave_function = force_psi_units(temp_wave_function,units='Meter')
     if not is_normalized(z,temp_wave_function,units = 'Meter'):
-        print('Psi after propagation was not normalized, Now it forces again normalization')
-        print(np.real(np.trapz(temp_wave_function * np.conj(temp_wave_function), z)))
-        temp_wave_function = temp_wave_function * normalize_wave_function_numerically(z,temp_wave_function,units='Meter')
+        temp = np.real(np.trapz(temp_wave_function * np.conj(temp_wave_function), z))
+        if not 0.97 <= temp <= 1.03:
+            print('Psi after propagation was not normalized, Now it forces again normalization')
+            print(np.real(np.trapz(temp_wave_function * np.conj(temp_wave_function), z)))
+            temp_wave_function = temp_wave_function * normalize_wave_function_numerically(z,temp_wave_function,units='Meter')
     return temp_wave_function
 
 def calculate_probability_current(wave_function, k):
@@ -1605,6 +1618,7 @@ def cumulative_probabilty(wave_function, z, z_cutoff, dz):
 def transmision_coeff(psi0,Nt,dt,v,z,k,z_position,path_to_save = None, final_time = None):
     '''
     Integration for the all time of simulation, summing all the probabilty currents, for each time-step in the simulation.
+
     Parameters
     ----------
     psi0 : np.array
