@@ -17,25 +17,25 @@ class Stage_1:
         Parameters
         ----------
         locpot_vec : `numpy.ndarray`, (N,2)
-                This is a 2 column matrix. The first colmn is ``z``, the spacial coordinates vector and second is ``v``, the local potential vector.
+                This is a 2 column matrix. The first colmn is ``z``, the spatial coordinates vector and second is ``v``, the local potential vector.
         E0 : float
                 The initial energy of the wave-function. Accounted to the total energy of an electron at the bottom of the cunduction band (CBM).
         sigma : float
                 The standard deviation of the guassian electron wave-pocket.
-        z_original : np.array, array_like, optional, defualt: None
-                The original, initial spacial coordinates vector.
-        Max_z_iterations : int, optional, defualt: 10
+        z_original : np.array, array_like, optional, default: None
+                The original, initial spatial coordinates vector.
+        Max_z_iterations : int, optional, default: 10
                 The maximum number of the iterations that the loop will be going through until convergence of the drid density.
-        Noriginal : int, optional, defualt: None
-                The initial/ original number of spacial steps, the number of `dx`'s in the spacial coordinates vector. If not
+        Noriginal : int, optional, default: None
+                The initial/ original number of spatial steps, the number of `dx`'s in the spatial coordinates vector. If not
                 supplied, it will take the value of ``len(z_original)``
-        allmin : `numpy.ndarray`, (N,2), defualt: None
+        allmin : `numpy.ndarray`, (N,2), default: None
                 This is a matrix with 2 columns. The first column holds the minimum points position, and the second column
                 holds the minimum points height. If not supplied it will take the matrix the resultd from
                 ``find_peaks_minima(self.locpot_vec[:, 0], self.locpot_vec[:, 1])``.
         To_plot : bool, optional, defulat: False
                 A flag to determine whether to plot or not.
-        allmax : `numpy.ndarray`, (N,2), defualt: None
+        allmax : `numpy.ndarray`, (N,2), default: None
                 This is a matrix with 2 columns. The first column holds the maximum points position, and the second column
                 holds the maximum points height. If not supplied it will take the matrix the resultd from
                 ``find_peaks_maxima(self.locpot_vec[:, 0], self.locpot_vec[:, 1])``.
@@ -72,10 +72,10 @@ class Stage_1:
 
         Parameters
         ----------
-        N : int/float, optional, defualt: None
+        N : int/float, optional, default: None
                 It can be delivered in order the determine the number of the samples
                 that the wavefunction will be constructed based on it.
-        Multi : int/float, optional, defualt: 5
+        Multi : int/float, optional, default: 5
                 If the initial unit is too small, you can choose
                 how many times to mulyiply it in order to produce the initial wavefucntion
                 matched the larger unit cell.
@@ -162,13 +162,13 @@ class Stage_1:
         Parameters
         ----------
         zz : np.array
-                Vector of the spacial grid. (spacial coordinates)
+                Vector of the spatial grid. (spatial coordinates)
         vv : np.array
                 Vector of the local potential.
         psi0 : np.array
                 The wave-function vector.
-        N : int, optional, defualt: None
-                The number of spacial steps, the number of `dx`'s.
+        N : int, optional, default: None
+                The number of spatial steps, the number of `dx`'s.
          '''
         zz = to_column_vec(zz)
         zz = self.cons.A2m(zz)
@@ -195,26 +195,26 @@ class Stage_1:
 
     def converge_main_axis_grid(self, tol = 0.001):
         '''
-        Converges the spacial grid of the system according to total energy difference of the tol parameter supplied
-        as an input. The difference relates to two consecutive iterations. It also demands that the spacial spacing not
+        Converges the spatial grid of the system according to total energy difference of the tol parameter supplied
+        as an input. The difference relates to two consecutive iterations. It also demands that the spatial spacing not
         be less than tol*sigma.
 
         Parameters
         ----------
-        tol : float, optional, defualt: 0.001
+        tol : float, optional, default: 0.001
                 It refers to tolerance. And it can make the condition for convergence
                 more or less strict.
 
         Returns
         -------
         zz_convg : np.array
-                The converged spacial grid vector.
+                The converged spatial grid vector.
         vv_convg : np.array
                 The converged local potential vector.
         psi0_convg : np.array
                 The converged wave function values vector.
         grid_density : float
-                The converged spacial grid density. It is defined as the number of the spacial points divided by the system length.
+                The converged spatial grid density. It is defined as the number of the spatial points divided by the system length.
         psi0_dic : dict
                 It holds all the necessary parameters that relate to the converged system and the convereged wave-function.
                 psi0_dic = {'k0' : , 'sigma':  , 'E0':  ,'zz': zz_convg, 'vv':vv_convg,'N': N_convg,'psi0':psi0_convg}
